## pwnpy

wardriving tool

### features:
- runs on any computer (can't remember having tested win though)
- fully automatic
- [modular](https://github.com/nbdy/pwnpy/tree/master/modules)
- [LiPo SHIM](https://shop.pimoroni.com/products/lipo-shim) <br>
    - you might want to use [this](https://github.com/nbdy/clean-shutdown)
- [2.9 inch ePaper display](https://www.waveshare.com/wiki/2.9inch_e-Paper_Module)

### show and tell
[![asciicast](https://asciinema.org/a/299821.svg)](https://asciinema.org/a/299821)
### how to...
#### .. install
```shell
pip3 install pwnpy
```
#### ...use it
```shell script
pwnpy -c config.json
```